==> digikam-2.4.1.tar.bz2: digikam-2.4.1/core/utilities/hotplug/digikam-gphoto2-camera.desktop.cmake <==
[Desktop Action digiKam Detect and Download]
Exec=@digikamhelperdir@/digikam-camera detect %u
Icon=digikam
Name=digiKam Detect and Download
Name[ast]=Deteutar y descargar con digiKam
Name[bg]=Откриване и изтегляне
Name[bs]=digiKam detekcija i preuzimanje
Name[ca]=Detecta i descarrega amb el digiKam
Name[ca@valencia]=Detecta i descarrega amb el digiKam
Name[cs]=Detekce a stahování digiKam
Name[da]=Detektér og download med digiKam
Name[de]=digiKam – Erkennen und herunterladen
Name[el]=digiKam ανίχνευση και λήψη
Name[en_GB]=digiKam Detect and Download
Name[es]=Detectar y descargar con digiKam
Name[et]=Fotode tuvastamine ja allalaadimine digiKamiga
Name[eu]=Detektatu eta deskargatu digiKam-ekin
Name[fi]=Tunnista kamera ja lataa kuvat digiKamilla
Name[fr]=Détection et téléchargement avec digiKam
Name[gl]=Detección e descarga de digiKam
Name[hne]=डिजिकैम पता लगिस अउ डाउनलोड करव
Name[hu]=digiKam keresés és letöltés
Name[is]=digiKam Finna og Hala niður
Name[it]=Rileva e scarica con digiKam
Name[ja]=digiKam 検出とダウンロード
Name[km]=រក​ឃើញ និង​ទាញយក digiKam
Name[lv]=digiKam noteicējs un ielādētājs
Name[nb]=digiKam «oppdag og last ned»
Name[nl]=Detecteren en downloaden
Name[pa]=ਡਿਜਿਕੈਮ ਖੋਜ ਅਤੇ ਡਾਊਨਲੋਡ
Name[pl]=Wykrywanie i pobieranie za pomocą digiKam
Name[pt]=Detectar e Transferir com o digiKam
Name[pt_BR]=Detectar e baixar com o digiKam
Name[ro]=Detectare și descărcare cu digiKam
Name[ru]=Копировать в digiKam
Name[sv]=Digikam detektering och nerladdning
Name[th]=ตรวจสอบและดาวน์โหลดด้วย digiKam
Name[tr]=digiKam Belirle ve İndir
Name[uk]=digiKam - виявлення і звантаження
Name[x-test]=xxdigiKam Detect and Downloadxx
Name[zh_CN]=digiKam 探测和下载
Name[zh_TW]=digiKam 偵測與下載

[Desktop Entry]
Encoding=UTF-8
Actions=digiKam Detect and Download;
ServiceTypes=KonqPopupMenu/Plugin,media/gphoto2camera
Type=Service

==> digikam-2.6.0.tar.bz2: digikam-2.6.0/core/utilities/hotplug/digikam-gphoto2-camera.desktop.cmake <==
[Desktop Action digiKam Detect and Download]
Exec=@digikamhelperdir@/digikam-camera detect %u
Icon=digikam
Name=digiKam Detect and Download
Name[ast]=Deteutar y descargar con digiKam
Name[bg]=Откриване и изтегляне
Name[bs]=digiKam detekcija i preuzimanje
Name[ca]=Detecta i descarrega amb el digiKam
Name[ca@valencia]=Detecta i descarrega amb el digiKam
Name[cs]=Detekce a stahování digiKam
Name[da]=Detektér og download med digiKam
Name[de]=digiKam – Erkennen und herunterladen
Name[el]=digiKam ανίχνευση και λήψη
Name[en_GB]=digiKam Detect and Download
Name[es]=Detectar y descargar con digiKam
Name[et]=Fotode tuvastamine ja allalaadimine digiKamiga
Name[eu]=Detektatu eta deskargatu digiKam-ekin
Name[fi]=Tunnista kamera ja lataa kuvat digiKamilla
Name[fr]=Détection et téléchargement avec digiKam
Name[gl]=Detección e descarga do digikam
Name[hne]=डिजिकैम पता लगिस अउ डाउनलोड करव
Name[hu]=digiKam keresés és letöltés
Name[is]=digiKam Finna og Hala niður
Name[it]=Rileva e scarica con digiKam
Name[ja]=digiKam 検出とダウンロード
Name[km]=រក​ឃើញ និង​ទាញយក digiKam
Name[lt]=digiKam aptikimas ir atsiuntimas
Name[lv]=digiKam noteicējs un ielādētājs
Name[nb]=digiKam «oppdag og last ned»
Name[nl]=Detecteren en downloaden
Name[pa]=ਡਿਜਿਕੈਮ ਖੋਜ ਅਤੇ ਡਾਊਨਲੋਡ
Name[pl]=Wykrywanie i pobieranie za pomocą digiKam
Name[pt]=Detectar e Transferir com o digiKam
Name[pt_BR]=Detectar e baixar com o digiKam
Name[ro]=Detectare și descărcare cu digiKam
Name[ru]=Копировать в digiKam
Name[sv]=Digikam detektering och nerladdning
Name[th]=ตรวจสอบและดาวน์โหลดด้วย digiKam
Name[tr]=digiKam Belirle ve İndir
Name[uk]=digiKam - виявлення і звантаження
Name[x-test]=xxdigiKam Detect and Downloadxx
Name[zh_CN]=digiKam 探测和下载
Name[zh_TW]=digiKam 偵測與下載

[Desktop Entry]
Encoding=UTF-8
Actions=digiKam Detect and Download;
ServiceTypes=KonqPopupMenu/Plugin,media/gphoto2camera
Type=Service
